@@ -3,6 +3,8 @@
 require "color"
 require "color/rgb/colors"
 
+require "pp"
+
 gem "minitest"
 require "minitest/autorun"
 require "minitest/focus"
@@ -18,5 +20,11 @@ module Minitest::ColorExtensions
     assert_in_delta expected, actual, Color::TOLERANCE, msg
   end
 
+  def assert_pretty_inspect(expected, object, msg = nil)
+    actual = PP.pp(object, +"", 8)
+
+    assert_equal expected, actual, message(msg, nil) { diff expected, actual }
+  end
+
   Minitest::Test.send(:include, self)
 end
